@@ -5,7 +5,7 @@
 # sudo wpa_supplicant -dd -Dnl80211,wext -i wlo1 -c /etc/wpa_supplicant/wpa_supplicant.conf 
 # NOTE: wlo1 can be substituted to your wireless interface
 
-our $VERSION = '0.031';
+our $VERSION = '0.032';
 sub BEGIN{
 
 no strict;
@@ -102,7 +102,9 @@ while(1){
 }
 
 =head1 NAME
+
 Wireless::Scanner - a small utility which scan near Bluetooth and Wifi networks
+
 =cut
 
 =head1 VERSION
@@ -116,28 +118,40 @@ current Version is the 0.02
 To install this module, run the following commands:
 
 perl Makefile.PL
+
 make
+
 // make test (STILL IN BETA, SKIPPING FOR NOW..)
+
 make install
 
 =cut
 
 =head1 MAIN USAGE
+
 sudo perl WirelessCan
-no args for now :(
+
+ [ no args for now :( ]
+
 =cut
 
 =head1 DESCRIPTION
 
 DETAILS   
+
 As the name suggests, this script scan the near networks, both bluetooth and wireless are shown in a pretty formatted output.
+
 I have uploaded an additional script 'Executor.pl', which can be used as CLI in the lower part of the screen.
+
 for additional info see the comments in the script.
+
 (the script need also the linux screen utility for the 'splitting screen feature').
 
+
 =cut 
 
 =head1 AUTHOR
+
 Edoardo Mantovani
  
 =cut
@@ -147,6 +161,7 @@ Edoardo Mantovani
    - The documentation will added during the project uodates, this is only an alpha, in future will be even more complex
    - Probably the bluetooth scan won't work, I am still working on it, BLE devices aren't recognized because I haven't found any BLE compatible module.
    - The script hasn't a Makefile.PL or make, for building the dependencies execute only the "install-deps.sh" script.
+
 =cut
 =head1 TODO
 
@@ -163,11 +178,15 @@ Edoardo Mantovani
   In a non-too-remote future I would like to built a library for controlling bluetooth 3.0 and BLE standard, I have some ideas related about the C library  which will be used. 
 
 =cut  
+
 =head1 FOR REQUESTS
+
 EMAIL ME :)
+
 =cut
 
 =head1 COPYRIGHT
+
        Copyright (c) 2020 Edoardo Mantovani, All Rights Reserved.
  
        This library is free software; you can redistribute it and/or modify it
